@@ -13,7 +13,7 @@ import json
 class TestReservationV2API(unittest.TestCase):
     ul.G_CLOUD_PROJECT = 'aura-staging-31cae'
     ul.ENCRYPTION_SECRET = "S1335HwpKYqEk9CM0I2hFX3oXa5T2oU86OXgMSW4s6U="
-    ul.MONGO_URI = access_secret_version(ul.G_CLOUD_PROJECT, 'MONGOURI', '1')
+    ul.MONGO_URI = access_secret_version(ul.G_CLOUD_PROJECT, 'MONGOURI', '5')
     ul.LOG_LEVEL_VALUE = logging.DEBUG
 
     def test_adding_new_RMS_reservation(self):
@@ -31,7 +31,7 @@ class TestReservationV2API(unittest.TestCase):
         firebase_admin.initialize_app(cred, name='alvie')
 
         resv = rms.ReservationSync('11281')
-        resv_list = [169410, 169411]
+        resv_list = [178859]
         for _resv_id in resv_list:
             start_time = datetime.datetime.now()
             print(f'processing reservation : {_resv_id}')
