@@ -7,7 +7,7 @@ import upswingutil as ul
 
 __PII_FIELDS__ = ['guestGiven', 'guestSurname', 'mobile', 'passportId', 'email', 'email2']
 
-mongoengine.connect(host='mongodb://AdminUpSwingGlobal:Upswing098812Admin0165r@35.200.226.24:27017/?authSource=admin&readPreference=primary&appname=util&directConnection=true&ssl=false')
+mongoengine.connect(host='mongodb://ReadWrite:gbyate0ewA712Dkq823gswX9i1oP@dev.db.upswing.global:27017/?authSource=admin&readPreference=primary&appname=Aura&ssl=false')
 
 
 class MongodbV2:
