@@ -147,33 +147,6 @@ def _generate_day_to_day_entry(record):
     return _daily_activity
 
 
-def _add_reservation_to_alvie(record):
-    firestore_db = Firestore(app='alvie')
-    user_email_list = [item["email"] for item in record.get('guests')]
-    resv_info = {
-        "_id": record.get("id"),
-        "agent": record.get("agent"),
-        "orgId": record.get("orgId"),
-        "areaId": record.get("areaId"),
-        "arrivalDate": record.get("arrivalDate"),
-        "departureDate": record.get("departureDate"),
-        "propertyId": record.get("propertyId"),
-        "propertyName": record.get("propertyName"),
-        "status": record.get("status"),
-        "travelAgentId": record.get("travelAgentId"),
-        "travelAgentName": record.get("travelAgentName")
-    }
-    logging.debug(f"Final reservation id : {record.get('id')}")
-    for email in user_email_list:
-        docs = firestore_db.get_collection('users').where("email", "==", email).stream()
-        for doc in docs:
-            logging.debug("loading reservation to alvie")
-            firestore_db.get_collection(f'users/{doc.id}/reservations') \
-                .document(str(record.get("id"))) \
-                .set(resv_info, merge=True)
-            logging.debug(f"added to {doc.id}")
-
-
 def _retrieve_data(session, id, name, url):
     result = None
     try:
@@ -196,12 +169,29 @@ class ReservationSync:
         self.orgId = orgId
         self.mongo = Mongodb(orgId)
         self.mongoV2 = MongodbV2(orgId)
+        self.firestore_db = Firestore(app='alvie')
         self.token: Token = get_key(self.orgId)
         self.g_cloud_token = g_cloud_token
         self.__urgent_booking_criteria__ = 5 * 86400
         self.__stay_duration_criteria__ = 10 * 86400
         self.__booking_category_levels__ = ['bronze', 'silver', 'gold', 'platinum']
 
+    def _add_reservation_to_alvie(self, record: ReservationModelV2):
+        try:
+            record = record.to_mongo()
+            for guest in record.get('guestInfo').get('guest_list'):
+                guest = dict(guest)
+                if guest.get('primary'):
+                    docs = self.firestore_db.get_collection(f'Organizations/{record.get("orgId")}/users')\
+                        .where("pmsGuestProfile", "==", guest.get('guest')).stream()
+                    for doc in docs:
+                        self.firestore_db.get_collection(f'Organizations/{record.get("orgId")}/users/{doc.id}/reservations')\
+                            .document(str(record.get('_id'))).set(record, merge=True)
+                        logging.info(f"{record.get('orgId')} : {record.get('_id')} added to {doc.id}")
+        except Exception as e:
+            logging.error(f'Error while storing reservation {record.get("orgId")} : {record.get("_id")} to firestore')
+            logging.error(e)
+
     def _get_booking_type(self, arrival_date: str, created_date: str):
         result = 'unknown'
         try:
@@ -271,7 +261,7 @@ class ReservationSync:
             firstName=record.get('guestGiven'),
             lastName=record.get('guestSurname'),
             datesAndDurations={
-                'birthDate': record.get('birthDate'),
+                'birthDate': record.get('birthday'),
                 'anniversary': None
             },
             address={
@@ -790,9 +780,9 @@ class ReservationSync:
             record = self.transform_reservation(self.extract_reservation_details(record))
             if record:
                 self.mongoV2.save(record)
+                self._add_reservation_to_alvie(record)
             else:
                 logging.error(f'Error saving the record {record} as it is None')
-            # self._add_reservation_to_alvie(record)
 
     def __del__(self):
         if self.mongo:
